DirEntry

Struct DirEntry 

pub struct DirEntry {
    dir: Arc<InnerReadDir>,
    entry: dirent64_min,
    name: CString,
}
Available on AIX or Android or FreeBSD or Fuchsia or GNU/Hurd or illumos or Linux or Play Station Vita or QNX SDP 7.x or QNX SDP 8.0+ or Redox OS or Solaris or WASI only.

Fields

dir: Arc<InnerReadDir>entry: dirent64_minname: CString

Implementations

Source

impl DirEntry

pub fn path(&self) -> PathBuf

pub fn file_name(&self) -> OsString

pub fn metadata(&self) -> Result<FileAttr>

Available on (Android, or Apple, or Fuchsia, or GNU/Hurd, or illumos, or Linux and non-musl) and non-miri only.
pub fn file_type(&self) -> Result<FileType>

Available on neither AIX nor Haiku nor illumos nor Play Station Vita nor QNX SDP 7.x nor QNX SDP 8.0+ nor Solaris nor VxWorks.
pub fn ino(&self) -> u64

Available on AIX or Android or Apple or Cygwin or Emscripten or ESP-IDF or FreeBSD or Fuchsia or GNU/Hurd or Haiku or Horizon or illumos or L4Re or Linux or Play Station Vita or QNX SDP 7.x or QNX SDP 8.0+ or Redox OS or RTEMS OS or Solaris or VxWorks or WASI only.
fn name_bytes(&self) -> &[u8]

Available on neither Apple nor DragonFly BSD nor NetBSD nor OpenBSD.
fn name_cstr(&self) -> &CStr

pub fn file_name_os_str(&self) -> &OsStr