pub struct FileAttr {
stat: stat64,
statx_extra_fields: Option<StatxExtraFields>,
}Fields
stat: stat64statx_extra_fields: Option<StatxExtraFields>Implementations
Sourceimpl FileAttr
impl FileAttr
pub fn modified(&self) -> Result<SystemTime>
Available on neither NetBSD nor QNX Neutrino nor AIX nor WASI and neither VxWorks nor ESP-IDF nor Horizon nor Play Station Vita nor GNU/Hurd nor RTEMS OS nor NuttX only.
pub fn accessed(&self) -> Result<SystemTime>
Available on neither NetBSD nor QNX Neutrino nor AIX nor WASI and neither VxWorks nor ESP-IDF nor Horizon nor Play Station Vita nor GNU/Hurd nor RTEMS OS nor NuttX only.
pub fn created(&self) -> Result<SystemTime>
Available on neither NetBSD nor QNX Neutrino nor AIX nor WASI and neither FreeBSD nor OpenBSD nor Play Station Vita nor Apple nor Cygwin only.