pub struct DirEntry {
dir: Arc<InnerReadDir>,
entry: dirent64_min,
name: CString,
}Available on AIX or Android or FreeBSD or Fuchsia or GNU/Hurd or illumos or Linux or QNX Neutrino or Redox OS or Solaris or Play Station Vita or WASI only.
Fields
dir: Arc<InnerReadDir>entry: dirent64_minname: CStringImplementations
Sourceimpl DirEntry
impl DirEntry
pub fn path(&self) -> PathBuf
pub fn file_name(&self) -> OsString
pub fn metadata(&self) -> Result<FileAttr>
Available on (Linux and non-musl, or Android, or Fuchsia, or GNU/Hurd, or illumos, or Apple) and non-
miri only.pub fn file_type(&self) -> Result<FileType>
Available on neither Solaris nor illumos nor Haiku nor VxWorks nor AIX nor QNX Neutrino nor Play Station Vita.
pub fn ino(&self) -> u64
Available on AIX or Android or Cygwin or Emscripten or ESP-IDF or FreeBSD or Fuchsia or Haiku or Horizon or GNU/Hurd or illumos or L4Re or Linux or QNX Neutrino or Redox OS or RTEMS OS or Solaris or Play Station Vita or VxWorks or WASI or Apple only.
fn name_bytes(&self) -> &[u8] ⓘ
Available on neither NetBSD nor OpenBSD nor DragonFly BSD nor Apple.
fn name_cstr(&self) -> &CStr
pub fn file_name_os_str(&self) -> &OsStr